Convenience unctions for running Integrant at the REPL. Follows the guidelines set out in Stuart Sierra's reloaded workflow. https://www.cognitect.com/blog/2013/06/04/clojure-workflow-reloaded
Convenience unctions for running Integrant at the REPL. Follows the guidelines set out in Stuart Sierra's reloaded workflow. https://www.cognitect.com/blog/2013/06/04/clojure-workflow-reloaded
(clear)Halt the running system and set the current configuration to nil.
Halt the running system and set the current configuration to nil.
(init)(init keys)Initiate the current configuration into a running system. Requires prep
to be called first to create the configuration. An optional collection of
keys may be supplied to initiate a subset of the configuration.
Initiate the current configuration into a running system. Requires [[prep]] to be called first to create the configuration. An optional collection of keys may be supplied to initiate a subset of the configuration.
(prep)Uses the function passed to set-prep! to load in an Integrant
configuration.
Uses the function passed to [[set-prep!]] to load in an Integrant configuration.
(reset-all)As reset, except that all namespaces are reloaded.
As [[reset]], except that *all* namespaces are reloaded.
(resume)Resume the system that has been suspended via suspend.
Resume the system that has been suspended via [[suspend]].
(set-prep! prep)Set the function that's called by prep. This function should take
zero arguments and return an Integrant configuration.
Set the function that's called by [[prep]]. This function should take zero arguments and return an Integrant configuration.
(set-reload-options! {:keys [dirs file-pattern]
:or {dirs nil file-pattern #".*\.cljc?"}})Set options for which files to reload when calling reset or
reset-all. Takes the following options:
:dirs
: a collection of directories to search for modified files. If nil,
then all local directories on the classpath are checked. Defaults to
nil.
:file-pattern
: only files matching this regular expression are checked. Defaults to
#".*\.cljc?".
Set options for which files to reload when calling [[reset]] or [[reset-all]]. Takes the following options: `:dirs` : a collection of directories to search for modified files. If `nil`, then all local directories on the classpath are checked. Defaults to `nil`. `:file-pattern` : only files matching this regular expression are checked. Defaults to `#".*\.cljc?"`.
(suspend)Suspend the running system so that it can be resumed later via resume.
Suspend the running system so that it can be resumed later via [[resume]].
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |